##  Deleting Relations
You can delete the added relations in fact sheets by following these steps:
  1. Hover over the relation and click the Edit button that appears in the upper right corner.
  2. In the bottom left corner, click Delete entry.
